@@ -1,4 +1,8 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 #
 # Copyright 2016-2017 David Steele <steele@debian.org>
@@ -15,7 +19,7 @@ import sys
 import uuid
 import getpass
 from functools import wraps
-import iwscan
+from comitup import iwscan
 
 
 import pprint
@@ -140,8 +144,7 @@ def get_access_points(device):
 
 def get_points_ext(device):
     try:
-        inlist = sorted(get_access_points(device),
-                        key=lambda x: -ord(x.Strength))
+        inlist = sorted(get_access_points(device), key=lambda x: -x.Strength)
     except (TypeError, dbus.exceptions.DBusException):
         log.debug("Error getting access points")
         inlist = []
@@ -157,7 +160,7 @@ def get_points_ext(device):
 
             outpoint = {
                 'ssid': point.Ssid,
-                'strength': str(ord(point.Strength)),
+                'strength': str(point.Strength),
                 'security': encstr,
                 'nmpath': point.object_path,
             }
@@ -232,7 +235,7 @@ def make_connection_for(ssid, password=None, interface=None):
             }),
         '802-11-wireless': dbus.Dictionary(
             {
-                'ssid': dbus.ByteArray(ssid),
+                'ssid': dbus.ByteArray(ssid.encode()),
                 'mode': 'infrastructure',
             }),
         'ipv4': dbus.Dictionary(
@@ -274,7 +277,7 @@ def do_listaccess(arg):
         row = (
             point.Ssid, point.HwAddress,
             point.Flags, point.WpaFlags,
-            point.RsnFlags, ord(point.Strength),
+            point.RsnFlags, point.Strength,
             point.Frequency
         )
         rows.append(row)
