@@ -1,4 +1,8 @@
 #!/usr/bin/python
+# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+#
+# SPDX-License-Identifier: GPL-2+
+# License-Filename: LICENSE
 
 
 from collections import namedtuple
@@ -12,19 +16,19 @@ log = logging.getLogger('comitup')
 
 
 def device_present():
-    if subprocess.check_output("iw list".split()) == "":
+    if subprocess.check_output("iw list".split()).decode() == "":
         # Fail without comment
         return ""
     return None
 
 
 def device_supports_ap():
-    devicesinfo = subprocess.check_output("iw list".split())
+    devicesinfo = subprocess.check_output("iw list".split()).decode()
 
     phy = devicesinfo.split()[1]
 
     cmd = "iw phy {} info".format(phy)
-    deviceinfo = subprocess.check_output(cmd.split())
+    deviceinfo = subprocess.check_output(cmd.split()).decode()
 
     if "* AP\n" not in deviceinfo:
         return phy
@@ -33,7 +37,7 @@ def device_supports_ap():
 
 
 def device_nm_managed():
-    devicesinfo = subprocess.check_output("nmcli device show".split(), re.MULTILINE)
+    devicesinfo = subprocess.check_output("nmcli device show".split(), re.MULTILINE).decode()
 
     if not re.search("GENERAL.TYPE\W+wifi", devicesinfo):
         # Fail without comment
@@ -87,11 +91,11 @@ def run_checks(logit=True, printit=True, verbose=True):
                     log.error("    " + testresult)
 
             if printit:
-                print testspec.title
+                print(testspec.title)
                 if testresult:
-                    print "    " + testresult
+                    print("    " + testresult)
                 if verbose:
-                    print testspec.description
+                    print(testspec.description)
             return True
 
     return None
